@@ -3,9 +3,10 @@
 ;; Copyright (C) 2022  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
+;; Maintainer: Fontaine Development <~protesilaos/fontaine@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/fontaine
-;; Mailing list: https://lists.sr.ht/~protesilaos/fontaine
-;; Version: 0.2.3
+;; Mailing-List: https://lists.sr.ht/~protesilaos/fontaine
+;; Version: 0.3.0
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -476,7 +477,7 @@ non-nil."
         (caar fontaine-presets)
       (fontaine--set-fonts-prompt))
     current-prefix-arg))
-  (if (not window-system)
+  (if (and (not (daemonp)) (not window-system))
       (user-error "Cannot use this in a terminal emulator; try the Emacs GUI")
     (fontaine--apply-default-preset preset frame)
     (fontaine--apply-fixed-pitch-preset preset frame)
